#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _0x5f__main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _imports_Theme_Theme_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_MainButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_GridBackground_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_HomeOverlay_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_NoDeviceOverlay_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_LinkButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_TransparentLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_TabPane_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_TextLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_DeviceInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_DeviceActions_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_SmallButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_SmallButtonRed_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_WindowControls_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_MainWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_ChannelDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_UpdateOverlay_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_CustomDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_ConfirmationDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_StatusBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_DeviceWidget_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_ChangelogDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_ExpandWidget_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_StreamOverlay_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_DirectionalKeypad_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_ImageButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_KeypadButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_TextView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_AbstractOverlay_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _imports_Primitives_AdvancedRectangle_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_FinishOverlay_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_SelfUpdateDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_DeveloperActions_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_TextBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_FileManager_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_FileManagerDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_ProgressDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _imports_Misc_FileTypes_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _imports_Misc_ErrorStrings_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_SDWarningDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_Button_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_ComboBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_Dialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_DialogButtonBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_IconLabelEx_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_Menu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_MenuItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_MenuSeparator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_ProgressBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_ScrollBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_ScrollView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_Switch_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_TabBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_TabButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _styles_DefaultAmber_ToolTip_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _imports_Primitives_ColorSet_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_WindowShadow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _imports_Misc_Mitigations_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _components_MessageDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/main.qml"), &QmlCacheGeneratedCode::_0x5f__main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/imports/Theme/Theme.qml"), &QmlCacheGeneratedCode::_imports_Theme_Theme_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/MainButton.qml"), &QmlCacheGeneratedCode::_components_MainButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/GridBackground.qml"), &QmlCacheGeneratedCode::_components_GridBackground_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/HomeOverlay.qml"), &QmlCacheGeneratedCode::_components_HomeOverlay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/NoDeviceOverlay.qml"), &QmlCacheGeneratedCode::_components_NoDeviceOverlay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/LinkButton.qml"), &QmlCacheGeneratedCode::_components_LinkButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/TransparentLabel.qml"), &QmlCacheGeneratedCode::_components_TransparentLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/TabPane.qml"), &QmlCacheGeneratedCode::_components_TabPane_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/TextLabel.qml"), &QmlCacheGeneratedCode::_components_TextLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/DeviceInfo.qml"), &QmlCacheGeneratedCode::_components_DeviceInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/DeviceActions.qml"), &QmlCacheGeneratedCode::_components_DeviceActions_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/SmallButton.qml"), &QmlCacheGeneratedCode::_components_SmallButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/SmallButtonRed.qml"), &QmlCacheGeneratedCode::_components_SmallButtonRed_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/WindowControls.qml"), &QmlCacheGeneratedCode::_components_WindowControls_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/MainWindow.qml"), &QmlCacheGeneratedCode::_components_MainWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/ChannelDelegate.qml"), &QmlCacheGeneratedCode::_components_ChannelDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/UpdateOverlay.qml"), &QmlCacheGeneratedCode::_components_UpdateOverlay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/CustomDialog.qml"), &QmlCacheGeneratedCode::_components_CustomDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/ConfirmationDialog.qml"), &QmlCacheGeneratedCode::_components_ConfirmationDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/StatusBar.qml"), &QmlCacheGeneratedCode::_components_StatusBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/DeviceWidget.qml"), &QmlCacheGeneratedCode::_components_DeviceWidget_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/ChangelogDialog.qml"), &QmlCacheGeneratedCode::_components_ChangelogDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/ExpandWidget.qml"), &QmlCacheGeneratedCode::_components_ExpandWidget_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/StreamOverlay.qml"), &QmlCacheGeneratedCode::_components_StreamOverlay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/DirectionalKeypad.qml"), &QmlCacheGeneratedCode::_components_DirectionalKeypad_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/ImageButton.qml"), &QmlCacheGeneratedCode::_components_ImageButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/KeypadButton.qml"), &QmlCacheGeneratedCode::_components_KeypadButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/TextView.qml"), &QmlCacheGeneratedCode::_components_TextView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/AbstractOverlay.qml"), &QmlCacheGeneratedCode::_components_AbstractOverlay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/imports/Primitives/AdvancedRectangle.qml"), &QmlCacheGeneratedCode::_imports_Primitives_AdvancedRectangle_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/FinishOverlay.qml"), &QmlCacheGeneratedCode::_components_FinishOverlay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/SelfUpdateDialog.qml"), &QmlCacheGeneratedCode::_components_SelfUpdateDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/DeveloperActions.qml"), &QmlCacheGeneratedCode::_components_DeveloperActions_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/TextBox.qml"), &QmlCacheGeneratedCode::_components_TextBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/FileManager.qml"), &QmlCacheGeneratedCode::_components_FileManager_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/FileManagerDelegate.qml"), &QmlCacheGeneratedCode::_components_FileManagerDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/ProgressDialog.qml"), &QmlCacheGeneratedCode::_components_ProgressDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/imports/Misc/FileTypes.qml"), &QmlCacheGeneratedCode::_imports_Misc_FileTypes_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/imports/Misc/ErrorStrings.qml"), &QmlCacheGeneratedCode::_imports_Misc_ErrorStrings_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/SDWarningDialog.qml"), &QmlCacheGeneratedCode::_components_SDWarningDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/Button.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_Button_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/ComboBox.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_ComboBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/Dialog.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_Dialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/DialogButtonBox.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_DialogButtonBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/IconLabelEx.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_IconLabelEx_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/Menu.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_Menu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/MenuItem.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_MenuItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/MenuSeparator.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_MenuSeparator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/ProgressBar.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_ProgressBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/ScrollBar.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_ScrollBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/ScrollView.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_ScrollView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/Switch.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_Switch_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/TabBar.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_TabBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/TabButton.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_TabButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/styles/DefaultAmber/ToolTip.qml"), &QmlCacheGeneratedCode::_styles_DefaultAmber_ToolTip_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/imports/Primitives/ColorSet.qml"), &QmlCacheGeneratedCode::_imports_Primitives_ColorSet_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/WindowShadow.qml"), &QmlCacheGeneratedCode::_components_WindowShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/imports/Misc/Mitigations.qml"), &QmlCacheGeneratedCode::_imports_Misc_Mitigations_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/components/MessageDialog.qml"), &QmlCacheGeneratedCode::_components_MessageDialog_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qml)() {
    ::unitRegistry();
    Q_INIT_RESOURCE(qml_qmlcache);
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qml))
int QT_MANGLE_NAMESPACE(qCleanupResources_qml)() {
    Q_CLEANUP_RESOURCE(qml_qmlcache);
    return 1;
}
