/****************************************************************************
** Meta object code from reading C++ file 'systemresponse.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../qflipper/plugins/flipperproto0/systemresponse.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systemresponse.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24SystemDeviceInfoResponseE_t {};
} // unnamed namespace

template <> constexpr inline auto SystemDeviceInfoResponse::qt_create_metaobjectdata<qt_meta_tag_ZN24SystemDeviceInfoResponseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SystemDeviceInfoResponse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SystemDeviceInfoResponse, qt_meta_tag_ZN24SystemDeviceInfoResponseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SystemDeviceInfoResponse::staticMetaObject = { {
    QMetaObject::SuperData::link<MainResponse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24SystemDeviceInfoResponseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24SystemDeviceInfoResponseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24SystemDeviceInfoResponseE_t>.metaTypes,
    nullptr
} };

void SystemDeviceInfoResponse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SystemDeviceInfoResponse *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *SystemDeviceInfoResponse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SystemDeviceInfoResponse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24SystemDeviceInfoResponseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "SystemDeviceInfoResponseInterface"))
        return static_cast< SystemDeviceInfoResponseInterface*>(this);
    if (!strcmp(_clname, "com.flipperdevices.SystemDeviceInfoResponseInterface/1.0"))
        return static_cast< SystemDeviceInfoResponseInterface*>(this);
    return MainResponse::qt_metacast(_clname);
}

int SystemDeviceInfoResponse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainResponse::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN25SystemGetDateTimeResponseE_t {};
} // unnamed namespace

template <> constexpr inline auto SystemGetDateTimeResponse::qt_create_metaobjectdata<qt_meta_tag_ZN25SystemGetDateTimeResponseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SystemGetDateTimeResponse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SystemGetDateTimeResponse, qt_meta_tag_ZN25SystemGetDateTimeResponseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SystemGetDateTimeResponse::staticMetaObject = { {
    QMetaObject::SuperData::link<MainResponse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25SystemGetDateTimeResponseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25SystemGetDateTimeResponseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25SystemGetDateTimeResponseE_t>.metaTypes,
    nullptr
} };

void SystemGetDateTimeResponse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SystemGetDateTimeResponse *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *SystemGetDateTimeResponse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SystemGetDateTimeResponse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25SystemGetDateTimeResponseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "SystemGetDateTimeResponseInterface"))
        return static_cast< SystemGetDateTimeResponseInterface*>(this);
    if (!strcmp(_clname, "com.flipperdevices.SystemGetDateTimeResponseInterface/1.0"))
        return static_cast< SystemGetDateTimeResponseInterface*>(this);
    return MainResponse::qt_metacast(_clname);
}

int SystemGetDateTimeResponse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainResponse::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN20SystemUpdateResponseE_t {};
} // unnamed namespace

template <> constexpr inline auto SystemUpdateResponse::qt_create_metaobjectdata<qt_meta_tag_ZN20SystemUpdateResponseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SystemUpdateResponse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SystemUpdateResponse, qt_meta_tag_ZN20SystemUpdateResponseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SystemUpdateResponse::staticMetaObject = { {
    QMetaObject::SuperData::link<MainResponse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SystemUpdateResponseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SystemUpdateResponseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20SystemUpdateResponseE_t>.metaTypes,
    nullptr
} };

void SystemUpdateResponse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SystemUpdateResponse *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *SystemUpdateResponse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SystemUpdateResponse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SystemUpdateResponseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "SystemUpdateResponseInterface"))
        return static_cast< SystemUpdateResponseInterface*>(this);
    if (!strcmp(_clname, "com.flipperdevices.SystemUpdateResponseInterface/1.0"))
        return static_cast< SystemUpdateResponseInterface*>(this);
    return MainResponse::qt_metacast(_clname);
}

int SystemUpdateResponse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainResponse::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN29SystemProtobufVersionResponseE_t {};
} // unnamed namespace

template <> constexpr inline auto SystemProtobufVersionResponse::qt_create_metaobjectdata<qt_meta_tag_ZN29SystemProtobufVersionResponseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SystemProtobufVersionResponse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SystemProtobufVersionResponse, qt_meta_tag_ZN29SystemProtobufVersionResponseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SystemProtobufVersionResponse::staticMetaObject = { {
    QMetaObject::SuperData::link<MainResponse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29SystemProtobufVersionResponseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29SystemProtobufVersionResponseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29SystemProtobufVersionResponseE_t>.metaTypes,
    nullptr
} };

void SystemProtobufVersionResponse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SystemProtobufVersionResponse *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *SystemProtobufVersionResponse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SystemProtobufVersionResponse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29SystemProtobufVersionResponseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "SystemProtobufVersionResponseInterface"))
        return static_cast< SystemProtobufVersionResponseInterface*>(this);
    if (!strcmp(_clname, "com.flipperdevices.SystemProtobufVersionResponseInterface/1.0"))
        return static_cast< SystemProtobufVersionResponseInterface*>(this);
    return MainResponse::qt_metacast(_clname);
}

int SystemProtobufVersionResponse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainResponse::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
