/****************************************************************************
** Meta object code from reading C++ file 'storageresponse.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../qflipper/plugins/flipperproto0/storageresponse.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'storageresponse.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19StorageInfoResponseE_t {};
} // unnamed namespace

template <> constexpr inline auto StorageInfoResponse::qt_create_metaobjectdata<qt_meta_tag_ZN19StorageInfoResponseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StorageInfoResponse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StorageInfoResponse, qt_meta_tag_ZN19StorageInfoResponseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StorageInfoResponse::staticMetaObject = { {
    QMetaObject::SuperData::link<MainResponse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageInfoResponseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageInfoResponseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19StorageInfoResponseE_t>.metaTypes,
    nullptr
} };

void StorageInfoResponse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageInfoResponse *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *StorageInfoResponse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StorageInfoResponse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageInfoResponseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "StorageInfoResponseInterface"))
        return static_cast< StorageInfoResponseInterface*>(this);
    if (!strcmp(_clname, "com.flipperdevices.StorageInfoResponseInterface/1.0"))
        return static_cast< StorageInfoResponseInterface*>(this);
    return MainResponse::qt_metacast(_clname);
}

int StorageInfoResponse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainResponse::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19StorageStatResponseE_t {};
} // unnamed namespace

template <> constexpr inline auto StorageStatResponse::qt_create_metaobjectdata<qt_meta_tag_ZN19StorageStatResponseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StorageStatResponse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StorageStatResponse, qt_meta_tag_ZN19StorageStatResponseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StorageStatResponse::staticMetaObject = { {
    QMetaObject::SuperData::link<MainResponse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageStatResponseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageStatResponseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19StorageStatResponseE_t>.metaTypes,
    nullptr
} };

void StorageStatResponse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageStatResponse *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *StorageStatResponse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StorageStatResponse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageStatResponseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "StorageStatResponseInterface"))
        return static_cast< StorageStatResponseInterface*>(this);
    if (!strcmp(_clname, "com.flipperdevices.StorageStatResponseInterface/1.0"))
        return static_cast< StorageStatResponseInterface*>(this);
    return MainResponse::qt_metacast(_clname);
}

int StorageStatResponse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainResponse::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19StorageListResponseE_t {};
} // unnamed namespace

template <> constexpr inline auto StorageListResponse::qt_create_metaobjectdata<qt_meta_tag_ZN19StorageListResponseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StorageListResponse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StorageListResponse, qt_meta_tag_ZN19StorageListResponseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StorageListResponse::staticMetaObject = { {
    QMetaObject::SuperData::link<MainResponse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageListResponseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageListResponseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19StorageListResponseE_t>.metaTypes,
    nullptr
} };

void StorageListResponse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageListResponse *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *StorageListResponse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StorageListResponse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageListResponseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "StorageListResponseInterface"))
        return static_cast< StorageListResponseInterface*>(this);
    if (!strcmp(_clname, "com.flipperdevices.StorageListResponseInterface/1.0"))
        return static_cast< StorageListResponseInterface*>(this);
    return MainResponse::qt_metacast(_clname);
}

int StorageListResponse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainResponse::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19StorageReadResponseE_t {};
} // unnamed namespace

template <> constexpr inline auto StorageReadResponse::qt_create_metaobjectdata<qt_meta_tag_ZN19StorageReadResponseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StorageReadResponse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StorageReadResponse, qt_meta_tag_ZN19StorageReadResponseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StorageReadResponse::staticMetaObject = { {
    QMetaObject::SuperData::link<MainResponse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageReadResponseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageReadResponseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19StorageReadResponseE_t>.metaTypes,
    nullptr
} };

void StorageReadResponse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageReadResponse *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *StorageReadResponse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StorageReadResponse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19StorageReadResponseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "StorageReadResponseInterface"))
        return static_cast< StorageReadResponseInterface*>(this);
    if (!strcmp(_clname, "com.flipperdevices.StorageReadResponseInterface/1.0"))
        return static_cast< StorageReadResponseInterface*>(this);
    return MainResponse::qt_metacast(_clname);
}

int StorageReadResponse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainResponse::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN21StorageMd5SumResponseE_t {};
} // unnamed namespace

template <> constexpr inline auto StorageMd5SumResponse::qt_create_metaobjectdata<qt_meta_tag_ZN21StorageMd5SumResponseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StorageMd5SumResponse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StorageMd5SumResponse, qt_meta_tag_ZN21StorageMd5SumResponseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StorageMd5SumResponse::staticMetaObject = { {
    QMetaObject::SuperData::link<MainResponse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21StorageMd5SumResponseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21StorageMd5SumResponseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21StorageMd5SumResponseE_t>.metaTypes,
    nullptr
} };

void StorageMd5SumResponse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageMd5SumResponse *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *StorageMd5SumResponse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StorageMd5SumResponse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21StorageMd5SumResponseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "StorageMd5SumResponseInterface"))
        return static_cast< StorageMd5SumResponseInterface*>(this);
    if (!strcmp(_clname, "com.flipperdevices.StorageMd5SumResponseInterface/1.0"))
        return static_cast< StorageMd5SumResponseInterface*>(this);
    return MainResponse::qt_metacast(_clname);
}

int StorageMd5SumResponse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainResponse::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
